<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'data', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   mod_data
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['action'] = 'Action';
$string['add'] = 'Add entry';
$string['addcomment'] = 'Add comment';
$string['addentries'] = 'Add entries';
$string['addtemplate'] = 'Add template';
$string['advancedsearch'] = 'Advanced search';
$string['allowcomments'] = 'Allow comments on entries';
$string['alttext'] = 'Alternative text';
$string['approvalstatus'] = 'Approval status';
$string['approve'] = 'Approve';
$string['approved'] = 'Approved';
$string['areacontent'] = 'Fields';
$string['ascending'] = 'Ascending';
$string['asearchtemplate'] = 'Advanced search template';
$string['atmaxentry'] = 'You have entered the maximum number of entries allowed!';
$string['authorfirstname'] = 'Author first name';
$string['authorlastname'] = 'Author surname';
$string['autogenallforms'] = 'Generate all default templates';
$string['autolinkurl'] = 'Autolink the URL';
$string['availablefromdate'] = 'Available from';
$string['availabletags'] = 'Available tags';
$string['availabletags_help'] = 'Tags are placeholders in the template, which will be replaced by data or other items, such as an edit icon, when entries are edited or viewed.

Fields have the format [[fieldname]]. All other tags have the format ##sometag##.

Only the tags that are in the "Available tags" list may be used for the current template.';
$string['availabletodate'] = 'Available to';
$string['availabletodatevalidation'] = 'The available to date cannot be before the available from date.';
$string['blank'] = 'Blank';
$string['buttons'] = 'Actions';
$string['bynameondate'] = 'by {$a->name} - {$a->date}';
$string['calendarend'] = '{$a} closes';
$string['calendarstart'] = '{$a} opens';
$string['cancel'] = 'Cancel';
$string['cannotaccesspresentsother'] = 'You are not allowed to access presets from other users';
$string['cannotadd'] = 'Can not add entries!';
$string['cannotdeletepreset'] = 'Error deleting a preset!';
$string['cannotoverwritepreset'] = 'Error overwriting preset';
$string['cannotunziptopreset'] = 'Cannot unzip to the preset directory';
$string['columns'] = 'columns';
$string['comment'] = 'Comment';
$string['commentdeleted'] = 'Comment deleted';
$string['commentempty'] = 'Comment was empty';
$string['comments'] = 'Comments';
$string['commentsaved'] = 'Comment saved';
$string['commentsn'] = '{$a} comment(s)';
$string['commentsoff'] = 'Comments feature is not enabled';
$string['completionentries'] = 'Require entries';
$string['completionentriescount'] = 'Count of entries';
$string['completionentriesdesc'] = 'Minimum number of entries required: {$a}';
$string['configenablerssfeeds'] = 'This switch will enable the possibility of RSS feeds for all databases. You will still need to turn feeds on manually in the settings for each database.';
$string['confirmdeletefield'] = 'You are about to delete this field, are you sure?';
$string['confirmdeleterecord'] = 'Are you sure you want to delete this entry?';
$string['confirmdeleterecords'] = 'Are you sure you want to delete these entries?';
$string['csstemplate'] = 'CSS template';
$string['csvfailed'] = 'Unable to read the raw data from the CSV file';
$string['csvfile'] = 'CSV file';
$string['csvimport'] = 'CSV file import';
$string['csvimport_help'] = 'Entries may be imported via a plain text file with a list of field names as the first line, then the data, with one record per line.';
$string['csvwithselecteddelimiter'] = '<acronym title="Comma Separated Values">CSV</acronym> text with selected delimiter:';
$string['data:addinstance'] = 'Add a new database';
$string['data:approve'] = 'Approve and undo approved entries';
$string['data:comment'] = 'Write comments';
$string['data:exportallentries'] = 'Export all database entries';
$string['data:exportentry'] = 'Export a database entry';
$string['data:exportownentry'] = 'Export own database entry';
$string['data:exportuserinfo'] = 'Export user information';
$string['data:managecomments'] = 'Manage comments';
$string['data:manageentries'] = 'Manage entries';
$string['data:managetemplates'] = 'Manage templates';
$string['data:manageuserpresets'] = 'Manage all template presets';
$string['data:rate'] = 'Rate entries';
$string['data:readentry'] = 'Read entries';
$string['data:viewalluserpresets'] = 'View presets from all users';
$string['data:viewallratings'] = 'View all raw ratings given by individuals';
$string['data:viewanyrating'] = 'View total ratings that anyone received';
$string['data:viewentry'] = 'View entries';
$string['data:viewrating'] = 'View the total rating you received';
$string['data:writeentry'] = 'Write entries';
$string['data:view'] = 'View database activity';
$string['date'] = 'Date';
$string['dateentered'] = 'Date entered';
$string['defaultfielddelimiter'] = '(default is the comma character)';
$string['defaultfieldenclosure'] = '(default is none)';
$string['defaultsortfield'] = 'Default sort field';
$string['delcheck'] = 'Bulk delete checkbox';
$string['delete'] = 'Delete';
$string['deleteallentries'] = 'Delete all entries';
$string['deletecomment'] = 'Are you sure you want to delete this comment?';
$string['deleted'] = 'deleted';
$string['deletefield'] = 'Delete an existing field';
$string['deletenotenrolled'] = 'Delete entries by users not enrolled';
$string['deletewarning'] = 'Are you sure you want to delete this preset?';
$string['descending'] = 'Descending';
$string['directorynotapreset'] = '{$a->directory} Not a preset: missing files: {$a->missing_files}';
$string['disapprove'] = 'Undo approval';
$string['download'] = 'Download';
$string['edit'] = 'Edit';
$string['editcomment'] = 'Edit comment';
$string['editentry'] = 'Edit entry';
$string['editordisable'] = 'Disable editor';
$string['editorenable'] = 'Enable editor';
$string['emptyadd'] = 'The Add template is empty, generating a default form...';
$string['emptyaddform'] = 'You did not fill out any fields!';
$string['enabletemplateeditorcheck'] = 'Are you sure you want to enable the editor? This may result in content being altered when the template is saved.';
$string['eventfieldcreated'] = 'Field created';
$string['eventfielddeleted'] = 'Field deleted';
$string['eventfieldupdated'] = 'Field updated';
$string['eventrecordcreated'] = 'Record created';
$string['eventrecorddeleted'] = 'Record deleted';
$string['eventrecordupdated'] = 'Record updated';
$string['eventtemplateupdated'] = 'Template updated';
$string['eventtemplateviewed'] = 'Templates viewed';
$string['fileencoding'] = 'Encoding';
$string['entries'] = 'Entries';
$string['entrieslefttoadd'] = 'You must add {$a->entriesleft} more entry/entries in order to complete this activity';
$string['entrieslefttoaddtoview'] = 'You must add {$a->entrieslefttoview} more entry/entries before you can view other participants\' entries.';
$string['entry'] = 'Entry';
$string['entrysaved'] = 'Your entry has been saved';
$string['errormustbeteacher'] = 'You need to be a teacher to use this page!';
$string['errorpresetexists'] = 'There is already a preset with the selected name';
$string['errormustsupplyvalue'] = 'You must supply a value here.';
$string['example'] = 'Database module example';
$string['excel'] = 'Excel';
$string['export'] = 'Export';
$string['exportaszip'] = 'Export as zip';
$string['exportaszip_help'] = 'The export as zip feature allows you to save the templates and fields as a preset zip for download. The zip may then be imported to another course.';
$string['exportedtozip'] = 'Exported to temporary zip...';
$string['exportentries'] = 'Export entries';
$string['exportownentries'] = 'Export your own entries only? ({$a->mine}/{$a->all})';
$string['failedpresetdelete'] = 'Error deleting a preset!';
$string['fieldadded'] = 'Field added';
$string['fieldallowautolink'] = 'Allow autolink';
$string['fielddeleted'] = 'Field deleted';
$string['fielddelimiter'] = 'Field delimiter';
$string['fielddescription'] = 'Field description';
$string['fieldenclosure'] = 'Field enclosure';
$string['fieldheight'] = 'Height';
$string['fieldheightlistview'] = 'Height in list view';
$string['fieldheightsingleview'] = 'Height in single view';
$string['fieldids'] = 'Field ids';
$string['fieldmappings'] = 'Field mappings';
$string['fieldmappings_help'] = 'This menu allows you to keep the data from the existing database. To preserve the data in a field, you must map it to a new field, where the data will appear. Any field can also be left blank, with no infomation copied into it. Any old field not mapped to a new one will be lost and all it\'s data removed.
You can only map fields of the same type, so each dropdown will have different fields in it. Also, you must be careful not to try and map one old field to more than one new field.';
$string['fieldname'] = 'Field name';
$string['fieldnotmatched'] = 'The following fields in your file are not known in this database: {$a}';
$string['fieldoptions'] = 'Options (one per line)';
$string['fields'] = 'Fields';
$string['fieldupdated'] = 'Field updated';
$string['fieldwidth'] = 'Width';
$string['fieldwidthlistview'] = 'Width in list view';
$string['fieldwidthsingleview'] = 'Width in single view';
$string['file'] = 'File';
$string['filesnotgenerated'] = 'Not all files were generated: {$a}';
$string['filtername'] = 'Database auto-linking';
$string['footer'] = 'Footer';
$string['forcelinkname'] = 'Forced name for the link';
$string['foundnorecords'] = 'No records found (<a href="{$a->reseturl}">Reset filters</a>)';
$string['foundrecords'] = 'Found records: {$a->num}/{$a->max} (<a href="{$a->reseturl}">Reset filters</a>)';
$string['fromfile'] = 'Import from zip file';
$string['fromfile_help'] = 'The import from zip file feature allows you to browse for and upload a preset zip of templates and fields.';
$string['generateerror'] = 'Not all files generated!';
$string['header'] = 'Header';
$string['headeraddtemplate'] = 'Defines the interface when editing entries';
$string['headerasearchtemplate'] = 'Defines the interface for Advanced Searches';
$string['headercsstemplate'] = 'Defines local CSS styles for the other templates';
$string['headerjstemplate'] = 'Defines custom Javascript for the other templates';
$string['headerlisttemplate'] = 'Defines browsing interface for multiple entries';
$string['headerrsstemplate'] = 'Defines appearance of entries in RSS feeds';
$string['headersingletemplate'] = 'Defines browsing interface for a single entry';
$string['checkbox'] = 'Checkbox';
$string['chooseexportfields'] = 'Choose the fields you wish to export:';
$string['chooseexportformat'] = 'Choose the format you wish to export to:';
$string['chooseorupload'] = 'Choose file';
$string['expired'] = 'Sorry, this activity closed on {$a} and is no longer available';
$string['importentries'] = 'Import entries';
$string['importsuccess'] = 'The preset has been successfully applied.';
$string['includeapproval'] = 'Include approval status';
$string['includetags'] = 'Include tags';
$string['includetime'] = 'Include time added/modified';
$string['includeuserdetails'] = 'Include user details';
$string['indicator:cognitivedepth'] = 'Database cognitive';
$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Database activity.';
$string['indicator:socialbreadth'] = 'Database social';
$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Database activity.';
$string['insufficiententries'] = 'more entries needed to view this database';
$string['intro'] = 'Description';
$string['invalidaccess'] = 'This page was not accessed correctly';
$string['invalidfieldid'] = 'Field ID is incorrect';
$string['invalidfieldname'] = 'Please choose another name for this field';
$string['invalidfieldtype'] = 'Field type is incorrect';
$string['invalidid'] = 'Incorrect data ID';
$string['invalidpreset'] = '{$a} is not a preset.';
$string['invalidrecord'] = 'Incorrect record';
$string['invalidurl'] = 'The URL you just entered is not valid';
$string['jstemplate'] = 'Javascript template';
$string['latitude'] = 'Latitude';
$string['latlong'] = 'Latitude/longitude';
$string['latlongboth'] = 'Both latitude and longitude are required.';
$string['latlongdownloadallhint'] = 'Download link for all entries as KML';
$string['latlongkmllabelling'] = 'How to label items in KML files (Google Earth)';
$string['latlonglinkservicesdisplayed'] = 'Link-out services to display';
$string['latlongotherfields'] = 'Other fields';
$string['list'] = 'View list';
$string['listtemplate'] = 'List template';
$string['longitude'] = 'Longitude';
$string['manageapproved'] = 'Allow editing of approved entries';
$string['manageapproved_help'] = 'If disabled, approved entries are no longer editable or deletable by the user who added them. This setting has no effect unless \'Approval required\' is enabled.';
$string['mapexistingfield'] = 'Map to {$a}';
$string['mapnewfield'] = 'Create a new field';
$string['mappingwarning'] = 'All old fields not mapped to a new field will be lost and all data in that field will be removed.';
$string['maxentries'] = 'Maximum number of entries';
$string['maxentries_help'] = 'The maximum number of entries a student is allowed to submit for this activity.';
$string['maxsize'] = 'Maximum size';
$string['menu'] = 'Menu';
$string['menuchoose'] = 'Choose...';
$string['missingdata'] = 'Data id or object must be provided to field class';
$string['missingfield'] = 'Programmer error: You must specify field and/or data when defining field class.';
$string['modulename'] = 'Database';
$string['modulename_help'] = 'The database activity module enables participants to create, maintain and search a collection of entries (i.e. records).  The structure of the entries is defined by the teacher as a number of fields. Field types include checkbox, radio buttons, dropdown menu, text area, URL, picture and uploaded file.

The visual layout of information when listing, viewing or editing database entries may be controlled by database templates. Database activities may be shared between courses as presets and a teacher may also import and export database entries.

If the database auto-linking filter is enabled, any entries in a database will be automatically linked where the words or phrases appear within the course.

A teacher can allow comments on entries. Entries can also be rated by teachers or students (peer evaluation). Ratings can be aggregated to form a final grade which is recorded in the gradebook.

Database activities have many uses, such as

* A collaborative collection of web links, books, book reviews, journal references etc
* For displaying student-created photos, posters, websites or poems for peer comment and review';
$string['modulename_link'] = 'mod/data/view';
$string['modulenameplural'] = 'Databases';
$string['more'] = 'More';
$string['moreurl'] = 'More URL';
$string['movezipfailed'] = 'Can\'t move zip';
$string['multientry'] = 'Repeated entry';
$string['multimenu'] = 'Menu (Multi-select)';
$string['multipletags'] = 'Multiple tags found! Template not saved';
$string['newentry'] = 'New entry';
$string['newfield'] = 'Create a new field';
$string['newfield_help'] = 'A field allows the input of data. Each entry in a database activity can have multiple fields of multiple types such as a date field, which allows participants to select a day, month and year from a dropdown list, a picture field, which allows participants to upload an image file, or a checkbox field, which allows participants to select one or more options.

Each field must have a unique field name. The field description is optional.';
$string['noaccess'] = 'You do not have access to this page';
$string['nodefinedfields'] = 'New preset has no defined fields!';
$string['nofieldcontent'] = 'Field content not found';
$string['nofieldindatabase'] = 'There are no fields defined for this database.';
$string['nolisttemplate'] = 'List template is not yet defined';
$string['nomatch'] = 'No matching entries found!';
$string['nomaximum'] = 'No maximum';
$string['norecords'] = 'No entries in database';
$string['nosingletemplate'] = 'Single template is not yet defined';
$string['notapproved'] = 'Entry is not approved yet.';
$string['notinjectivemap'] = 'Not an injective map';
$string['notopenyet'] = 'Sorry, this activity is not available until {$a}';
$string['number'] = 'Number';
$string['numberrssarticles'] = 'Entries in the RSS feed';
$string['numnotapproved'] = 'Pending';
$string['numrecords'] = '{$a} entries';
$string['ods'] = '<acronym title="OpenDocument Spreadsheet">ODS</acronym> (OpenOffice)';
$string['optionaldescription'] = 'Short description (optional)';
$string['optionalfilename'] = 'Filename (optional)';
$string['other'] = 'Other';
$string['overwrite'] = 'Overwrite';
$string['overrwritedesc'] = 'Overwrite the preset if it already exists';
$string['overwritesettings'] = 'Overwrite current settings';
$string['page-mod-data-x'] = 'Any database activity module page';
$string['pagesize'] = 'Entries per page';
$string['participants'] = 'Participants';
$string['picture'] = 'Picture';
$string['pleaseaddsome'] = 'Please create some below or <a href="{$a}">choose a predefined set</a> to get started.';
$string['pluginadministration'] = 'Database activity administration';
$string['pluginname'] = 'Database';
$string['portfolionotfile'] = 'Export to a portfolio rather than a file (csv and leap2a only)';
$string['presetinfo'] = 'Saving as a preset will publish this template. Other users may be able to use it in their databases.';
$string['presets'] = 'Presets';
$string['privacy:metadata:commentpurpose'] = 'Comments on database records';
$string['privacy:metadata:data_content'] = 'Represents one answer to one field in database activity module';
$string['privacy:metadata:data_content:fieldid'] = 'Field definition ID';
$string['privacy:metadata:data_content:content'] = 'Content';
$string['privacy:metadata:data_content:content1'] = 'Additional content 1';
$string['privacy:metadata:data_content:content2'] = 'Additional content 2';
$string['privacy:metadata:data_content:content3'] = 'Additional content 3';
$string['privacy:metadata:data_content:content4'] = 'Additional content 4';
$string['privacy:metadata:data_records'] = 'Represent records in database acitivity module';
$string['privacy:metadata:data_records:userid'] = 'User who created the record';
$string['privacy:metadata:data_records:groupid'] = 'Group';
$string['privacy:metadata:data_records:timecreated'] = 'Time when record was created';
$string['privacy:metadata:data_records:timemodified'] = 'Time when record was last modified';
$string['privacy:metadata:data_records:approved'] = 'Approval status';
$string['privacy:metadata:datafieldnpluginsummary'] = 'Fields for database activity module';
$string['privacy:metadata:filepurpose'] = 'File attached to the database record';
$string['privacy:metadata:tagpurpose'] = 'Tags on database records';
$string['privacy:metadata:ratingpurpose'] = 'Ratings on database records';
$string['radiobutton'] = 'Radio buttons';
$string['recordapproved'] = 'Entry approved';
$string['recorddeleted'] = 'Entry deleted';
$string['recorddisapproved'] = 'Entry unapproved';
$string['recordsnotsaved'] = 'No entry was saved. Please check the format of the uploaded file.';
$string['recordssaved'] = 'entries saved';
$string['removealldatatags'] = 'Remove all database tags';
$string['requireapproval'] = 'Approval required';
$string['requireapproval_help'] = 'If enabled, entries require approving by a teacher before they are viewable by everyone.';
$string['required'] = 'Required';
$string['requiredentries'] = 'Entries required for completion (old)';
$string['requiredentries_help'] = "If set, a message is displayed stating the number of entries required for completion. Note that this setting is not connected to activity completion.

For entries required for activity completion, the new Activity completion setting 'Require entries' should be used. To remove this setting completely, set to none, then save changes.
Please use the Entries required fields in the Activity completion section instead.";
$string['requiredentrieswarning'] = 'This setting has been replaced by an Activity completion setting "Require entries"';
$string['requiredentriestoview'] = 'Entries required before viewing';
$string['requiredentriestoview_help'] = 'The number of entries a student is required to submit before they can view entries from other students.

Note: If entries are required before viewing, the database auto-linking filter should be disabled. This is because the database auto-linking filter can\'t determine whether a user has submitted the required number of entries.';
$string['requiredfield'] = 'Required field';
$string['resetsettings'] = 'Reset filters';
$string['resettemplate'] = 'Reset template';
$string['resizingimages'] = 'Resizing image thumbnails...';
$string['rows'] = 'rows';
$string['rssglobaldisabled'] = 'Disabled. See site configuration variables.';
$string['rsstemplate'] = 'RSS template';
$string['rsstitletemplate'] = 'RSS title template';
$string['save'] = 'Save';
$string['saveandadd'] = 'Save and add another';
$string['saveandview'] = 'Save and view';
$string['saveaspreset'] = 'Save as preset';
$string['saveaspreset_help'] = 'The save as preset feature publishes the templates and fields as a preset which others on the site can then use. (You may delete it from the list of presets at any time.)';
$string['savesettings'] = 'Save settings';
$string['savesuccess'] = 'Saved successfully. Your preset will now be available across the site.';
$string['savetemplate'] = 'Save template';
$string['search'] = 'Search';
$string['search:activity'] = 'Database - activity information';
$string['search:entry'] = 'Database - entries';
$string['selectedrequired'] = 'All selected required';
$string['showall'] = 'Show all entries';
$string['single'] = 'View single';
$string['singletemplate'] = 'Single template';
$string['subplugintype_datafield'] = 'Database field type';
$string['subplugintype_datafield_plural'] = 'Database field types';
$string['subplugintype_datapreset'] = 'Preset';
$string['subplugintype_datapreset_plural'] = 'Presets';
$string['tagarea_data_records'] = 'Data records';
$string['tags'] = 'Tags';
$string['tagsdeleted'] = 'Database tags have been deleted';
$string['teachersandstudents'] = '{$a->teachers} and {$a->students}';
$string['templates'] = 'Templates';
$string['templatesaved'] = 'Template saved';
$string['text'] = 'Text';
$string['textarea'] = 'Textarea';
$string['timeadded'] = 'Time added';
$string['timemodified'] = 'Time modified';
$string['todatabase'] = 'to this database.';
$string['type'] = 'Field type';
$string['undefinedprocessactionmethod'] = 'No action method defined in Data_Preset to handle action "{$a}".';
$string['unsupportedexport'] = '({$a->fieldtype}) cannot be exported.';
$string['updatefield'] = 'Update an existing field';
$string['uploadfile'] = 'Upload file';
$string['uploadrecords'] = 'Upload entries from a file';
$string['uploadrecords_help'] = 'Entries may be uploaded via text file. The format of the file should be as follows:

* Each line of the file contains one record
* Each record is a series of data separated by commas (or other delimiters)
* The first record contains a list of fieldnames defining the format of the rest of the file

The field enclosure is a character that surrounds each field in each record. It can normally be left unset.';
$string['uploadrecords_link'] = 'mod/data/import';
$string['url'] = 'Url';
$string['usedate'] = 'Include in search.';
$string['usestandard'] = 'Use a preset';
$string['usestandard_help'] = 'To use a preset available to the whole site, select it from the list. (If you have added a preset to the list using the save as preset feature then you have the option of deleting it.)';
$string['viewfromdate'] = 'Read only from';
$string['viewtodate'] = 'Read only to';
$string['viewtodatevalidation'] = 'The read only to date cannot be before the read only from date.';
$string['wrongdataid'] = 'Wrong data id provided';

// Deprecated since Moodle 3.2.
$string['namedate'] = 'Date field';
$string['namefile'] = 'File field';
$string['namecheckbox'] = 'Checkbox field';
$string['namelatlong'] = 'Latitude/longitude field';
$string['namemenu'] = 'Menu field';
$string['namemultimenu'] = 'Multiple-selection menu field';
$string['namenumber'] = 'Number field';
$string['namepicture'] = 'Picture field';
$string['nameradiobutton'] = 'Radio button field';
$string['nametext'] = 'Text field';
$string['nametextarea'] = 'Textarea field';
$string['nameurl'] = 'URL field';
